@@ -2,9 +2,6 @@
 The tests here do not correspond directly to the OpenJPEG test suite, but
 seem like logical negative tests to add.
 """
-# E1101:  assertWarns introduced in python 3.2
-# pylint: disable=E1101
-
 # R0904:  Not too many methods in unittest.
 # pylint: disable=R0904
 
@@ -15,6 +12,7 @@ import os
 import re
 import sys
 import tempfile
+import warnings
 
 if sys.hexversion < 0x02070000:
     import unittest2 as unittest
@@ -64,15 +62,15 @@ class TestSuiteNegative(unittest.TestCase):
         jp2k.get_codestream(header_only=False)
         self.assertTrue(True)
 
-    @unittest.skipIf(sys.hexversion < 0x03020000,
-                     "Uses features introduced in 3.2.")
     def test_nr_illegalclrtransform(self):
         """EOC marker is bad"""
         relpath = 'input/nonregression/illegalcolortransform.j2k'
         jfile = opj_data_file(relpath)
         jp2k = Jp2k(jfile)
-        with self.assertWarns(UserWarning):
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter("always")
             codestream = jp2k.get_codestream(header_only=False)
+            self.assertEqual(len(w), 1)
 
         # Verify that the last segment returned in the codestream is SOD,
         # not EOC.  Codestream parsing should stop when we try to jump to
@@ -106,8 +104,6 @@ class TestSuiteNegative(unittest.TestCase):
             with self.assertRaises(IOError):
                 j.write(data, cbsize=(2, 2048))
 
-    @unittest.skipIf(sys.hexversion < 0x03020000,
-                     "Uses features introduced in 3.2.")
     def test_exceeded_box(self):
         """should warn if reading past end of a box"""
         # Verify that a warning is issued if we read past the end of a box
@@ -115,7 +111,8 @@ class TestSuiteNegative(unittest.TestCase):
         # short.
         infile = os.path.join(OPJ_DATA_ROOT,
                               'input/nonregression/mem-b2ace68c-1381.jp2')
-        with self.assertWarns(UserWarning):
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter("ignore")
             Jp2k(infile)
 
     @unittest.skipIf(os.name == "nt", "Temporary file issue on window.")
