@@ -35,7 +35,9 @@ else:
 
 import glymur
 from glymur import Jp2k
+from . import fixtures
 from .fixtures import OPJ_DATA_ROOT, opj_data_file
+from .fixtures import text_gbr_27, text_gbr_33, text_gbr_34
 
 
 @unittest.skipIf(os.name == "nt", "Temporary file issue on window.")
@@ -185,31 +187,23 @@ class TestPrintingNeedsLib(unittest.TestCase):
                 expected = '\n'.join(lines)
                 self.assertEqual(actual, expected)
 
+    @unittest.skipIf(sys.hexversion < 0x02070000, "Do not bother with 2.6")
     def test_jp2dump(self):
         """basic jp2dump test"""
         with patch('sys.stdout', new=StringIO()) as fake_out:
-            glymur.jp2dump(self._plain_nemo_file)
+            glymur.jp2dump(glymur.data.nemo())
             actual = fake_out.getvalue().strip()
 
         # Get rid of the filename line, as it is not set in stone.
         lst = actual.split('\n')
         lst = lst[1:]
         actual = '\n'.join(lst)
-        self.assertEqual(actual, self.expected_plain)
-
-    def test_entire_file(self):
-        """verify output from printing entire file"""
-        j = glymur.Jp2k(self._plain_nemo_file)
-        with patch('sys.stdout', new=StringIO()) as fake_out:
-            print(j)
-            actual = fake_out.getvalue().strip()
-
-        # Get rid of the filename line, as it is not set in stone.
-        lst = actual.split('\n')
-        lst = lst[1:]
-        actual = '\n'.join(lst)
-
-        self.assertEqual(actual, self.expected_plain)
+        self.maxDiff = None
+        if sys.hexversion < 0x02080000:
+            # Ordered dicts are different in 2.7
+            self.assertEqual(actual, fixtures.nemo_dump_full_p27)
+        else:
+            self.assertEqual(actual, fixtures.nemo_dump_full_opj2)
 
 
 class TestPrinting(unittest.TestCase):
@@ -287,70 +281,25 @@ class TestPrinting(unittest.TestCase):
     @unittest.skipIf(OPJ_DATA_ROOT is None,
                      "OPJ_DATA_ROOT environment variable not set")
     def test_icc_profile(self):
-        """verify printing of colr box with ICC profile"""
+        """verify icc profile printing with a jpx"""
+        # ICC profiles may be used in JP2, but the approximation field should
+        # be zero unless we have jpx.  This file does both.
         filename = opj_data_file('input/nonregression/text_GBR.jp2')
         with warnings.catch_warnings():
             # brand is 'jp2 ', but has any icc profile.
             warnings.simplefilter("ignore")
             jp2 = Jp2k(filename)
+
         with patch('sys.stdout', new=StringIO()) as fake_out:
             print(jp2.box[3].box[1])
             actual = fake_out.getvalue().strip()
-        lin27 = ["Colour Specification Box (colr) @ (179, 1339)",
-                 "    Method:  any ICC profile",
-                 "    Precedence:  2",
-                 "    Approximation:  accurately represents correct "
-                 + "colorspace definition",
-                 "    ICC Profile:",
-                 "        {'Color Space': 'RGB',",
-                 "         'Connection Space': 'XYZ',",
-                 "         'Creator': u'appl',",
-                 "         'Datetime': "
-                 + "datetime.datetime(2009, 2, 25, 11, 26, 11),",
-                 "         'Device Attributes': 'reflective, glossy, "
-                 + "positive media polarity, color media',",
-                 "         'Device Class': 'display device profile',",
-                 "         'Device Manufacturer': u'appl',",
-                 "         'Device Model': '',",
-                 "         'File Signature': u'acsp',",
-                 "         'Flags': "
-                 + "'not embedded, can be used independently',",
-                 "         'Illuminant': "
-                 + "array([ 0.96420288,  1.        ,  0.8249054 ]),",
-                 "         'Platform': u'APPL',",
-                 "         'Preferred CMM Type': 1634758764,",
-                 "         'Rendering Intent': 'perceptual',",
-                 "         'Size': 1328,",
-                 "         'Version': '2.2.0'}"]
-        lin33 = ["Colour Specification Box (colr) @ (179, 1339)",
-                 "    Method:  any ICC profile",
-                 "    Precedence:  2",
-                 "    Approximation:  accurately represents correct "
-                 + "colorspace definition",
-                 "    ICC Profile:",
-                 "        {'Size': 1328,",
-                 "         'Preferred CMM Type': 1634758764,",
-                 "         'Version': '2.2.0',",
-                 "         'Device Class': 'display device profile',",
-                 "         'Color Space': 'RGB',",
-                 "         'Connection Space': 'XYZ',",
-                 "         'Datetime': "
-                 + "datetime.datetime(2009, 2, 25, 11, 26, 11),",
-                 "         'File Signature': 'acsp',",
-                 "         'Platform': 'APPL',",
-                 "         'Flags': 'not embedded, can be used "
-                 + "independently',",
-                 "         'Device Manufacturer': 'appl',",
-                 "         'Device Model': '',",
-                 "         'Device Attributes': 'reflective, glossy, "
-                 + "positive media polarity, color media',",
-                 "         'Rendering Intent': 'perceptual',",
-                 "         'Illuminant': "
-                 + "array([ 0.96420288,  1.        ,  0.8249054 ]),",
-                 "         'Creator': 'appl'}"]
+        if sys.hexversion < 0x03000000:
+            expected = text_gbr_27
+        elif sys.hexversion < 0x03040000:
+            expected = text_gbr_33
+        else:
+            expected = text_gbr_34
 
-        lines = lin27 if sys.hexversion < 0x03000000 else lin33
-        expected = '\n'.join(lines)
         self.assertEqual(actual, expected)
 
     @unittest.skipIf(OPJ_DATA_ROOT is None,
@@ -980,7 +929,7 @@ class TestPrinting(unittest.TestCase):
     @unittest.skipIf(OPJ_DATA_ROOT is None,
                      "OPJ_DATA_ROOT environment variable not set")
     def test_jpx_approx_icc_profile(self):
-        """verify jpx with approx field equal to zero"""
+        """verify icc profile printing with a jpx"""
         # ICC profiles may be used in JP2, but the approximation field should
         # be zero unless we have jpx.  This file does both.
         filename = opj_data_file('input/nonregression/text_GBR.jp2')
@@ -992,34 +941,13 @@ class TestPrinting(unittest.TestCase):
         with patch('sys.stdout', new=StringIO()) as fake_out:
             print(jp2.box[3].box[1])
             actual = fake_out.getvalue().strip()
-        lines = ["Colour Specification Box (colr) @ (179, 1339)",
-                 "    Method:  any ICC profile",
-                 "    Precedence:  2",
-                 "    Approximation:  accurately represents "
-                 + "correct colorspace definition",
-                 "    ICC Profile:",
-                 "        {'Size': 1328,",
-                 "         'Preferred CMM Type': 1634758764,",
-                 "         'Version': '2.2.0',",
-                 "         'Device Class': 'display device profile',",
-                 "         'Color Space': 'RGB',",
-                 "         'Connection Space': 'XYZ',",
-                 "         'Datetime': "
-                 + "datetime.datetime(2009, 2, 25, 11, 26, 11),",
-                 "         'File Signature': 'acsp',",
-                 "         'Platform': 'APPL',",
-                 "         'Flags': 'not embedded, "
-                 + "can be used independently',",
-                 "         'Device Manufacturer': 'appl',",
-                 "         'Device Model': '',",
-                 "         'Device Attributes': 'reflective, glossy, "
-                 + "positive media polarity, color media',",
-                 "         'Rendering Intent': 'perceptual',",
-                 "         'Illuminant': array([ 0.96420288,  1.        ,"
-                 + "  0.8249054 ]),",
-                 "         'Creator': 'appl'}"]
+        if sys.hexversion < 0x03000000:
+            expected = text_gbr_27
+        elif sys.hexversion < 0x03040000:
+            expected = text_gbr_33
+        else:
+            expected = text_gbr_34
 
-        expected = '\n'.join(lines)
         self.assertEqual(actual, expected)
 
     @unittest.skipIf(OPJ_DATA_ROOT is None,
